| Title: | An RKWard plugin to reshape data by pivoting it longer or wider using functions from the 'tidyr' package. |
|---|---|
| Description: | An RKWard plugin to reshape data by pivoting it longer or wider using functions from the 'tidyr' package. |
| Authors: | Alfonso Cano Robles |
| Maintainer: | Alfonso Cano Robles <[email protected]> |
| License: | GPL (>= 3) |
| Version: | 0.01.10 |
| Built: | 2026-06-04 09:55:08 UTC |
| Source: | https://github.com/AlfCano/rk.pivot.reshape |